@@ -88,7 +88,7 @@ struct _PulseaudioButton
   gint                  icon_size;
   const gchar          *icon_name;
 
-  GtkWidget            *menu;
+  PulseaudioMenu       *menu;
 
   gulong                volume_changed_id;
   gulong                deactivate_id;
@@ -137,8 +137,10 @@ pulseaudio_button_init (PulseaudioButton *button)
 
   /* Setup Gtk style */
   css_provider = gtk_css_provider_new ();
-  gtk_css_provider_load_from_data (css_provider, "#pulseaudio-button { -GtkWidget-focus-padding: 0; -GtkWidget-focus-line-width: 0; -GtkButton-default-border: 0; -GtkButton-inner-border: 0; padding: 1px; border-width: 1px;}", -1, NULL);
-  gtk_style_context_add_provider (GTK_STYLE_CONTEXT (gtk_widget_get_style_context (GTK_WIDGET (button))), GTK_STYLE_PROVIDER (css_provider), GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+  gtk_css_provider_load_from_data (css_provider, ".xfce4-panel button { padding: 1px; }", -1, NULL);
+  gtk_style_context_add_provider (GTK_STYLE_CONTEXT (gtk_widget_get_style_context (GTK_WIDGET (button))),
+                                  GTK_STYLE_PROVIDER (css_provider),
+                                  GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
 
   /* Intercept scroll events */
   gtk_widget_add_events (GTK_WIDGET (button), GDK_SCROLL_MASK);
@@ -239,8 +241,6 @@ pulseaudio_button_scroll_event (GtkWidget *widget, GdkEventScroll *event)
   pulseaudio_volume_set_volume (button->volume, new_volume);
   //g_debug ("dir: %d %f -> %f", event->direction, volume, new_volume);
 
-  pulseaudio_notify (button->plugin);
-
   return TRUE;
 }
 
@@ -282,6 +282,7 @@ pulseaudio_button_update (PulseaudioButton *button,
                           gboolean          force_update)
 {
   gdouble      volume;
+  gboolean     connected;
   gboolean     muted;
   gchar       *tip_text;
   const gchar *icon_name;
@@ -291,7 +292,10 @@ pulseaudio_button_update (PulseaudioButton *button,
 
   volume = pulseaudio_volume_get_volume (button->volume);
   muted = pulseaudio_volume_get_muted (button->volume);
-  if (muted)
+  connected = pulseaudio_volume_get_connected (button->volume);
+  if (!connected)
+    icon_name = icons[V_MUTED];
+  else if (muted)
     icon_name = icons[V_MUTED];
   else if (volume <= 0.0)
     icon_name = icons[V_MUTED];
@@ -302,7 +306,9 @@ pulseaudio_button_update (PulseaudioButton *button,
   else
     icon_name = icons[V_HIGH];
 
-  if (muted)
+  if (!connected)
+    tip_text = g_strdup_printf (_("Not connected to the PulseAudio server"));
+  else if (muted)
     tip_text = g_strdup_printf (_("Volume %d%% (muted)"), (gint) round (volume * 100));
   else
     tip_text = g_strdup_printf (_("Volume %d%%"), (gint) round (volume * 100));
@@ -320,48 +326,32 @@ pulseaudio_button_update (PulseaudioButton *button,
 
 void
 pulseaudio_button_set_size (PulseaudioButton *button,
-                            gint              size)
+                            gint              size,
+                            gint              icon_size)
 {
-  GtkStyleContext  *context;
-  GtkBorder         padding;
-  GtkBorder         border;
-  gint              width;
-  gint              xthickness;
-  gint              ythickness;
-  gint              size_old;
-
   g_return_if_fail (IS_PULSEAUDIO_BUTTON (button));
   g_return_if_fail (size > 0);
 
-  /* Get widget's padding and border to correctly calculate the button's icon size */
-  context = gtk_widget_get_style_context (GTK_WIDGET (button));
-  gtk_style_context_get_padding (context, gtk_widget_get_state_flags (GTK_WIDGET (button)), &padding);
-  gtk_style_context_get_border (context, gtk_widget_get_state_flags (GTK_WIDGET (button)), &border);
-  xthickness = padding.left+padding.right+border.left+border.right;
-  ythickness = padding.top+padding.bottom+border.top+border.bottom;
-
-  width = size - 2* MAX (xthickness, ythickness);
-  /* Since symbolic icons are usually only provided in 16px we
-   * try to be clever and use size steps */
-  size_old = button->icon_size;
-  if (width <= 21)
-      button->icon_size = 16;
-  else if (width >=22 && width <= 29)
-      button->icon_size = 24;
-  else if (width >= 30 && width <= 40)
-      button->icon_size = 32;
-  else
-      button->icon_size = width;
-
   gtk_widget_set_size_request (GTK_WIDGET (button), size, size);
-  if (button->icon_size != size_old)
-    pulseaudio_button_update_icons (button);
+  button->icon_size = icon_size;
+  gtk_image_set_pixel_size (GTK_IMAGE (button->image), button->icon_size);
+}
+
+
+
+PulseaudioMenu *
+pulseaudio_button_get_menu (PulseaudioButton *button)
+{
+  g_return_val_if_fail (IS_PULSEAUDIO_BUTTON (button), NULL);
+
+  return button->menu;
 }
 
 
 
 static void
 pulseaudio_button_volume_changed (PulseaudioButton  *button,
+                                  gboolean           should_notify,
                                   PulseaudioVolume  *volume)
 {
   g_return_if_fail (IS_PULSEAUDIO_BUTTON (button));
@@ -371,7 +361,7 @@ pulseaudio_button_volume_changed (PulseaudioButton  *button,
 
 
 
-GtkWidget *
+PulseaudioButton *
 pulseaudio_button_new (PulseaudioPlugin *plugin,
                        PulseaudioConfig *config,
                        PulseaudioVolume *volume)
@@ -393,7 +383,7 @@ pulseaudio_button_new (PulseaudioPlugin *plugin,
 
   pulseaudio_button_update (button, TRUE);
 
-  return GTK_WIDGET (button);
+  return button;
 }
 
 
