@@ -21,8 +21,10 @@
 #include <glib.h>
 #include <gtk/gtk.h>
 
+#include "pulseaudio-plugin.h"
+#include "pulseaudio-config.h"
 #include "pulseaudio-volume.h"
-//#include "pulseaudio-config.h"
+#include "pulseaudio-menu.h"
 
 G_BEGIN_DECLS
 
@@ -38,12 +40,15 @@ GType pulseaudio_button_get_type (void);
 typedef struct          _PulseaudioButton              PulseaudioButton;
 typedef struct          _PulseaudioButtonClass         PulseaudioButtonClass;
 
-GtkWidget              *pulseaudio_button_new         (PulseaudioPlugin *plugin,
+PulseaudioButton       *pulseaudio_button_new         (PulseaudioPlugin *plugin,
                                                        PulseaudioConfig *config,
                                                        PulseaudioVolume *volume);
 
 void                    pulseaudio_button_set_size    (PulseaudioButton *button,
-                                                       gint              size);
+                                                       gint              size,
+                                                       gint              icon_size);
+
+PulseaudioMenu         *pulseaudio_button_get_menu    (PulseaudioButton *button);
 
 G_END_DECLS
 
