@@ -23,7 +23,9 @@
  *
  */
 
-
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
 
 #include <glib.h>
 #include <gtk/gtk.h>
@@ -182,6 +184,7 @@ pulseaudio_menu_run_audio_mixer (PulseaudioMenu   *menu,
 
 static void
 pulseaudio_menu_volume_changed (PulseaudioMenu   *menu,
+                                gboolean          should_notify,
                                 PulseaudioVolume *volume)
 {
   g_return_if_fail (IS_PULSEAUDIO_MENU (menu));
@@ -201,7 +204,7 @@ pulseaudio_menu_volume_changed (PulseaudioMenu   *menu,
 
 
 
-GtkWidget *
+PulseaudioMenu *
 pulseaudio_menu_new (PulseaudioVolume *volume,
                      PulseaudioConfig *config,
                      GtkWidget        *widget)
@@ -270,10 +273,10 @@ pulseaudio_menu_new (PulseaudioVolume *volume,
   gtk_menu_shell_append (GTK_MENU_SHELL (menu), mi);
   g_signal_connect_swapped (G_OBJECT (mi), "activate", G_CALLBACK (pulseaudio_menu_run_audio_mixer), menu);
 
-  pulseaudio_menu_volume_changed (menu, menu->volume);
+  pulseaudio_menu_volume_changed (menu, FALSE, menu->volume);
 
 
-  return GTK_WIDGET (menu);
+  return menu;
 }
 
 
