@@ -1,4 +1,4 @@
-/*  Copyright (c) 2014-2015 Andrzej <ndrwrdck@gmail.com>
+/*  Copyright (c) 2014-2017 Andrzej <ndrwrdck@gmail.com>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public License
@@ -95,7 +95,7 @@ struct _PulseaudioPlugin
 #endif
 
   /* panel widgets */
-  GtkWidget           *button;
+  PulseaudioButton    *button;
 
   /* config dialog builder */
   PulseaudioDialog    *dialog;
@@ -211,7 +211,7 @@ pulseaudio_plugin_show_about (XfcePanelPlugin *plugin)
                          "program-name", PACKAGE_NAME,
                          "comments",     _("Adjust the audio volume of the PulseAudio sound system"),
                          "website",      "http://goodies.xfce.org/projects/panel-plugins/xfce4-pulseaudio-plugin",
-                         "copyright",    _("Copyright \xc2\xa9 2014 Andrzej Radecki\n"),
+                         "copyright",    _("Copyright \xc2\xa9 2014-2017 Andrzej Radecki\n"),
                          "authors",      auth,
                          NULL);
 
@@ -237,11 +237,17 @@ pulseaudio_plugin_size_changed (XfcePanelPlugin *plugin,
                                 gint             size)
 {
   PulseaudioPlugin *pulseaudio_plugin = PULSEAUDIO_PLUGIN (plugin);
+  gint              icon_size;
 
   /* The plugin only occupies a single row */
   size /= xfce_panel_plugin_get_nrows (plugin);
+#if LIBXFCE4PANEL_CHECK_VERSION (4,13,0)
+  icon_size = xfce_panel_plugin_get_icon_size (plugin);
+#else
+  icon_size = size - 2; // fall-back for older panel versions
+#endif
 
-  pulseaudio_button_set_size (PULSEAUDIO_BUTTON (pulseaudio_plugin->button), size);
+  pulseaudio_button_set_size (pulseaudio_plugin->button, size, icon_size);
 
   return TRUE;
 }
@@ -266,7 +272,7 @@ static gboolean
 pulseaudio_plugin_bind_keys (PulseaudioPlugin      *pulseaudio_plugin)
 {
   gboolean success;
-  g_return_if_fail (IS_PULSEAUDIO_PLUGIN (pulseaudio_plugin));
+  g_return_val_if_fail (IS_PULSEAUDIO_PLUGIN (pulseaudio_plugin), FALSE);
   pulseaudio_debug ("Grabbing volume control keys");
 
   success = (keybinder_bind (PULSEAUDIO_PLUGIN_LOWER_VOLUME_KEY, pulseaudio_plugin_volume_key_pressed, pulseaudio_plugin) &&
@@ -359,16 +365,17 @@ pulseaudio_plugin_construct (XfcePanelPlugin *plugin)
   /* volume controller */
   pulseaudio_plugin->volume = pulseaudio_volume_new (pulseaudio_plugin->config);
 
-  /* initialize notify wrapper */
-#ifdef HAVE_LIBNOTIFY
-  pulseaudio_plugin->notify = pulseaudio_notify_new (pulseaudio_plugin->config,
-                                                     pulseaudio_plugin->volume);
-#endif
-
   /* instantiate a button box */
   pulseaudio_plugin->button = pulseaudio_button_new (pulseaudio_plugin,
                                                      pulseaudio_plugin->config,
                                                      pulseaudio_plugin->volume);
+  /* initialize notify wrapper */
+#ifdef HAVE_LIBNOTIFY
+  pulseaudio_plugin->notify = pulseaudio_notify_new (pulseaudio_plugin->config,
+                                                     pulseaudio_plugin->volume,
+                                                     pulseaudio_plugin->button);
+#endif
+
   gtk_container_add (GTK_CONTAINER (plugin), GTK_WIDGET (pulseaudio_plugin->button));
   gtk_widget_show (GTK_WIDGET (pulseaudio_plugin->button));
 
